@@ -152,7 +152,7 @@ void ConfigureDialog::setSchemeList(){
 	cB_batteryScheme->clear();
 
 	for ( TQStringList::Iterator it = schemes.begin(); it != schemes.end(); ++it ) {
-		const char *_tmp = (*it).ascii();
+		const char *_tmp = (*it).utf8();
 		if((*it) == "Performance" || (*it) == i18n("Performance")) {
 			listBox_schemes->insertItem(SmallIcon("scheme_power", TQIconSet::Automatic), i18n(_tmp));
 			cB_acScheme->insertItem(i18n(_tmp));
@@ -1288,7 +1288,7 @@ void ConfigureDialog::setInactivityBox(){
 	// actions.append("Turn Off Computer");
 
 	for ( TQStringList::Iterator it = actions.begin(); it != actions.end(); ++it ) {
-		cB_autoInactivity->insertItem( i18n( (*it).ascii() ) );
+		cB_autoInactivity->insertItem( i18n( (*it).utf8() ) );
 	}
 
 	kdDebugFuncOut(trace);
